@@ -152,10 +152,12 @@ pub trait PanelState {
             Internal::close_panel_ok => CmdResult::ClosePanel {
                 validate_purpose: true,
                 panel_ref: PanelReference::Active,
+                clear_cache: true,
             },
             Internal::close_panel_cancel => CmdResult::ClosePanel {
                 validate_purpose: false,
                 panel_ref: PanelReference::Active,
+                clear_cache: false,
             },
             Internal::move_panel_divider => {
                 let MoveDividerArgs { divider, dx } = get_arg(
@@ -482,6 +484,38 @@ pub trait PanelState {
 					con,
 				)
             }
+            Internal::set_max_depth => {
+                let args = input_invocation.and_then(|inv| inv.args.as_ref());
+
+                if let Some(flags) = args {
+                    self.with_new_options(
+                        screen,
+                        &|o| {
+                            if let Ok(max_depth) = flags.parse::<u16>() {
+                                o.max_depth = Some(max_depth);
+                                "*max depth updated*"
+                            } else {
+                                "*depth must be an integer*"
+                            }
+                        },
+                        bang,
+                        con,
+                    )
+                } else {
+                    CmdResult::error(":set_max_depth needs a depth as an argument")
+                }
+            }
+            Internal::unset_max_depth => {
+                self.with_new_options(
+                        screen,
+                        &|o| {
+                        o.max_depth = None;
+                        "*cleared max depth*"
+                    },
+                    bang,
+                    con,
+                )
+            }
             Internal::toggle_git_ignore | Internal::toggle_ignore => {
                 self.with_new_options(
 					screen,
@@ -577,6 +611,7 @@ pub trait PanelState {
                     CmdResult::ClosePanel {
                         validate_purpose: false,
                         panel_ref: PanelReference::Id(id),
+                        clear_cache: false,
                     }
                 } else {
                     CmdResult::Keep
@@ -607,6 +642,7 @@ pub trait PanelState {
                     CmdResult::ClosePanel {
                         validate_purpose: false,
                         panel_ref: PanelReference::Id(panel_id),
+                        clear_cache: false,
                     }
                 } else {
                     CmdResult::Keep
@@ -620,6 +656,7 @@ pub trait PanelState {
                     CmdResult::ClosePanel {
                         validate_purpose: false,
                         panel_ref: PanelReference::Id(id),
+                        clear_cache: false,
                     }
                 } else {
                     CmdResult::Keep
@@ -641,6 +678,7 @@ pub trait PanelState {
                     CmdResult::ClosePanel {
                         validate_purpose: false,
                         panel_ref: PanelReference::Id(id),
+                        clear_cache: false,
                     }
                 } else {
                     CmdResult::NewPanel {
@@ -685,6 +723,9 @@ pub trait PanelState {
                 }
                 CmdResult::Keep
             }
+            internal if internal.is_input_related() => {
+                CmdResult::HandleInApp(internal)
+            }
             _ => CmdResult::Keep,
         })
     }
@@ -724,6 +765,7 @@ pub trait PanelState {
                     return CmdResult::ClosePanel {
                         validate_purpose: false,
                         panel_ref: PanelReference::Id(panel_id),
+                        clear_cache: false,
                     };
                 }
             }
@@ -791,6 +833,7 @@ pub trait PanelState {
                     return Ok(CmdResult::ClosePanel {
                         validate_purpose: false,
                         panel_ref: PanelReference::Id(id),
+                        clear_cache: true,
                     });
                 }
             }
@@ -943,6 +986,7 @@ pub trait PanelState {
                 CmdResult::ClosePanel {
                     validate_purpose: false,
                     panel_ref: PanelReference::Id(id),
+                    clear_cache: false,
                 }
             } else if preferred_mode.is_some() {
                 // we'll make the preview mode change be
@@ -1117,7 +1161,7 @@ pub trait PanelState {
                     );
                 }
             }
-            // right now there's no check for sequences but they're inherently dangereous
+            // right now there's no check for sequences but they're inherently dangerous
         }
         if let Some(err) = verb.check_args(sel_info, invocation, &app_state.other_panel_path) {
             Status::new(err, true)
