@@ -330,6 +330,7 @@ impl PanelState for BrowserState {
         app_state: &mut AppState,
         cc: &CmdContext,
     ) -> Result<CmdResult, ProgramError> {
+        debug!("browser_state on_internal {:?}", internal_exec);
         let con = &cc.app.con;
         let screen = cc.app.screen;
         let page_height = BrowserState::page_height(cc.app.screen);
@@ -623,6 +624,7 @@ impl PanelState for BrowserState {
                     CmdResult::ClosePanel {
                         validate_purpose: true,
                         panel_ref: PanelReference::Active,
+                        clear_cache: false,
                     }
                 } else {
                     debug!("start_end understood as start");
@@ -767,7 +769,7 @@ impl PanelState for BrowserState {
                     }
                 }
                 BrowserTask::StageAll { pattern, file_type_condition } => {
-                    info!("stage all pattern: {:?}", pattern);
+                    debug!("stage all pattern: {:?}", pattern);
                     let tree = self.displayed_tree();
                     let root = tree.root().clone();
                     let mut options = tree.options.clone();
@@ -781,7 +783,7 @@ impl PanelState for BrowserState {
                                 total_search,
                                 dam,
                                 |line| {
-                                    info!("??staging {:?}", &line.path);
+                                    debug!("??staging {:?}", &line.path);
                                     file_type_condition.accepts_path(&line.path)
                                 }
                             ))
